@@ -1,6 +1,6 @@
 package Ubic::Service::SimpleDaemon;
 BEGIN {
-  $Ubic::Service::SimpleDaemon::VERSION = '1.28';
+  $Ubic::Service::SimpleDaemon::VERSION = '1.29';
 }
 
 use strict;
@@ -110,15 +110,14 @@ Ubic::Service::SimpleDaemon - variant of service when your service is simple dae
 
 =head1 VERSION
 
-version 1.28
+version 1.29
 
 =head1 SYNOPSIS
 
     use Ubic::Service::SimpleDaemon;
-    my $service = Ubic::Service::SimpleDaemon->new({
-        name => "sleep",
-        bin => "sleep 1000",
-    });
+    my $service = Ubic::Service::SimpleDaemon->new(
+        bin => "sleep 1000"
+    );
 
 =head1 DESCRIPTION
 
